Please visit [Pyrustic](https://github.com/pyrustic/pyrustic#readme).


<!-- Image -->
<div align="center">
    <img src="https://raw.githubusercontent.com/pyrustic/misc/master/media/cover.png" alt="Cover">
    <br>
    <p align="center">
    The Pyrustic software suite with the cyberpunk theme
    </p>
</div>